@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -64,7 +64,7 @@ ColumnMetadataTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "blobValue": bytes,
+        "blobValue": Union[bytes, IO[bytes]],
         "booleanValue": bool,
         "doubleValue": float,
         "isNull": bool,
